@@ -25,6 +25,7 @@ Place, Suite 330, Boston, MA 02111-1307 USA.
 
 import os, re
 import bb.data
+import bb.utils
 
 class Event:
     """Base class for events"""
@@ -43,20 +44,26 @@ class Event:
 
 NotHandled = 0
 Handled = 1
-handlers = []
+
+Registered        = 10
+AlreadyRegistered = 14
+
+# Internal
+_handlers = []
+_handlers_dict = {}
 
 def tmpHandler(event):
     """Default handler for code events"""
     return NotHandled
 
 def defaultTmpHandler():
-    tmp = "def tmpHandler(e):\n\t\"\"\"heh\"\"\"\n\treturn 0"
-    comp = compile(tmp, "tmpHandler(e)", "exec")
+    tmp = "def tmpHandler(e):\n\t\"\"\"heh\"\"\"\n\treturn NotHandled"
+    comp = bb.utils.better_compile(tmp, "tmpHandler(e)", "bb.event.defaultTmpHandler")
     return comp
 
 def fire(event):
     """Fire off an Event"""
-    for h in handlers:
+    for h in _handlers:
         if type(h).__name__ == "code":
             exec(h)
             if tmpHandler(event) == Handled:
@@ -66,17 +73,24 @@ def fire(event):
                 return Handled
     return NotHandled
 
-def register(handler):
+def register(name, handler):
     """Register an Event handler"""
+
+    # already registered
+    if name in _handlers_dict:
+        return AlreadyRegistered
+
     if handler is not None:
 #       handle string containing python code
         if type(handler).__name__ == "str":
-            return registerCode(handler)
-#       prevent duplicate registration
-        if not handler in handlers:
-            handlers.append(handler)
+            _registerCode(handler)
+        else:
+            _handlers.append(handler)
 
-def registerCode(handlerStr):
+        _handlers_dict[name] = 1
+        return Registered
+
+def _registerCode(handlerStr):
     """Register a 'code' Event.
        Deprecated interface; call register instead.
 
@@ -85,26 +99,25 @@ def registerCode(handlerStr):
        the code will be within a function, so should have had
        appropriate tabbing put in place."""
     tmp = "def tmpHandler(e):\n%s" % handlerStr
-    comp = compile(tmp, "tmpHandler(e)", "exec")
+    comp = bb.utils.better_compile(tmp, "tmpHandler(e)", "bb.event._registerCode")
 #   prevent duplicate registration
-    if not comp in handlers:
-        handlers.append(comp)
+    _handlers.append(comp)
 
-def remove(handler):
+def remove(name, handler):
     """Remove an Event handler"""
-    for h in handlers:
-        if type(handler).__name__ == "str":
-            return removeCode(handler)
 
-        if handler is h:
-            handlers.remove(handler)
+    _handlers_dict.pop(name)
+    if type(handler).__name__ == "str":
+        return _removeCode(handler)
+    else:
+        _handlers.remove(handler)
 
-def removeCode(handlerStr):
+def _removeCode(handlerStr):
     """Remove a 'code' Event handler
        Deprecated interface; call remove instead."""
     tmp = "def tmpHandler(e):\n%s" % handlerStr
-    comp = compile(tmp, "tmpHandler(e)", "exec")
-    handlers.remove(comp)
+    comp = bb.utils.better_compile(tmp, "tmpHandler(e)", "bb.event._removeCode")
+    _handlers.remove(comp)
 
 def getName(e):
     """Returns the name of a class or class instance"""
@@ -117,7 +130,7 @@ def getName(e):
 class PkgBase(Event):
     """Base class for package events"""
 
-    def __init__(self, t, d = {}):
+    def __init__(self, t, d = bb.data.init()):
         self._pkg = t
         Event.__init__(self, d)
 
@@ -133,10 +146,11 @@ class PkgBase(Event):
 class BuildBase(Event):
     """Base class for bbmake run events"""
 
-    def __init__(self, n, p, c):
+    def __init__(self, n, p, c, failures = 0):
         self._name = n
         self._pkgs = p
         Event.__init__(self, c)
+        self._failures = failures
 
     def getPkgs(self):
         return self._pkgs
@@ -156,6 +170,12 @@ class BuildBase(Event):
     def setCfg(self, cfg):
         self.data = cfg
 
+    def getFailures(self):
+        """
+        Return the number of failed packages
+        """
+        return self._failures
+
     pkgs = property(getPkgs, setPkgs, None, "pkgs property")
     name = property(getName, setName, None, "name property")
     cfg = property(getCfg, setCfg, None, "cfg property")
@@ -204,7 +224,43 @@ class UnsatisfiedDep(DepBase):
 class RecursiveDep(DepBase):
     """Recursive Dependency"""
 
+class NoProvider(Event):
+    """No Provider for an Event"""
 
-class MultipleProviders(PkgBase):
+    def __init__(self, item, data,runtime=False):
+        Event.__init__(self, data)
+        self._item = item
+        self._runtime = runtime
+
+    def getItem(self):
+        return self._item
+
+    def isRuntime(self):
+        return self._runtime
+
+class MultipleProviders(Event):
     """Multiple Providers"""
 
+    def  __init__(self, item, candidates, data, runtime = False):
+        Event.__init__(self, data)
+        self._item = item
+        self._candidates = candidates
+        self._is_runtime = runtime
+
+    def isRuntime(self):
+        """
+        Is this a runtime issue?
+        """
+        return self._is_runtime
+
+    def getItem(self):
+        """
+        The name for the to be build item
+        """
+        return self._item
+
+    def getCandidates(self):
+        """
+        Get the possible Candidates for a PROVIDER.
+        """
+        return self._candidates
