@@ -24,18 +24,23 @@ THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef LEXER_H
 #define LEXER_H
 
+#include "Python.h"
+
+extern "C" {
+	
 struct lex_t {
-    void *parser;
-    void *scanner;
+    void* parser;
+    void* scanner;
+    FILE* file;    
+    PyObject *data;
+    
     void* (*parse)(void*, int, token_t, lex_t*);
 
-    void accept(int token, const char* string = 0);
-    void input(char *buf, int *result, int_max_size);
+    void accept(int token, const char* sz = NULL);
+    void input(char *buf, int *result, int max_size);
     int  line()const;
-    const char* filename()const;
-private:
-    const char* m_fileName;
 };
 
+}
 
 #endif
